@@ -4,8 +4,8 @@ class ParameterErrorException(Exception):
 
 
 class MethodNotAllowedErrorException(Exception):
-    def __init__(self, message):
-        super().__init__(message)
+    def __init__(self, method, url):
+        super().__init__('%s method not allowed for %s' % (method, url))
 
 
 class ServiceErrorException(Exception):
@@ -16,3 +16,12 @@ class ServiceErrorException(Exception):
 class NetworkErrorException(Exception):
     def __init__(self, message):
         super().__init__(message)
+
+
+class NoResourcesException(Exception):
+    def __init__(self, message):
+        super().__init__(message)
+
+class ClientErrorException(Exception):
+    def __init__(self, message):
+        super().__init__(message)
