@@ -41,6 +41,9 @@ class OssFileCache():
         @param file_path: 文件路径 url|本地目录|本地文件
         @param del_local: 缓存后是否删除本地文件
         """
+        if not os.path.exists(file_path) and not re.match("http", file_path):
+            raise FileNotFoundError(file_path)
+
         local_path = '/tmp/%s.%s' % (self.random_str(30), self.random_str(30))
         cache_path = "%s/%s/%s" % (self.cache_path_root, self.namespace, key)
 
